from terrasnek.api import TFC


def get_workspace_output(tfc: TFC, org_name: str, workspace_name: str, output_name: str) -> str:
    tfc.set_org(org_name=org_name)
    response = tfc.workspaces.show(workspace_name=workspace_name)
    current_state_version = response["data"]["relationships"]["current-state-version"]
    current_state_version_id = current_state_version["data"]["id"]
    response = tfc.state_versions.list_state_version_outputs(current_state_version_id)
    for output in response["data"]:
        attrs = output["attributes"]
        if attrs["name"] == output_name:
            return attrs["value"]
    raise LookupError(
        f"Failed to find output in workspace: {org_name}/{workspace_name}/{output_name}"
    )



import typer
from terrasnek.api import TFC

from .terraform_cloud import get_workspace_output

app = typer.Typer()
tfc_token_opt = typer.Option(
    default=...,
    envvar=["TFE_TOKEN", "TFC_TOKEN"],
    help="Terraform Cloud access token",
    is_eager=True,
)


@app.command(name="get-output")
def get_output(
    workspace_ref: str = typer.Argument(
        default=...,
        help="Reference to a Terraform Cloud workspace in "
        "'<org_name>/<workspace_name>/<output_name>' format.",
    ),
    tfc_token: str = tfc_token_opt,
):
    """Get the value of a Terraform Cloud workspace output.

    For example: `python -m tfc_utils get-output hashicorp/primary-workspace/instance_ip_addr`
    """
    tfc = TFC(api_token=tfc_token)
    try:
        org, workspace, output = workspace_ref.split("/")
    except ValueError as e:
        raise ValueError(
            "Invalid Terraform output reference, must be in "
            "'<org_name>/<workspace_name>/<output_name>' format"
        ) from e
    output = get_workspace_output(tfc, org, workspace, output)
    typer.echo(output)


@app.callback()
def callback():
    """A CLI helper tool for Terraform Cloud."""
